pub struct SchedSample {Show 28 fields
pub mseq: u64,
pub pid: i32,
pub comm: String,
pub stat: String,
pub cpu_id: u32,
pub prev_cpu_id: u32,
pub suggested_cpu_id: u32,
pub waker_pid: i32,
pub waker_comm: String,
pub slice_wall: u64,
pub slice_used_wall: u64,
pub lat_cri: u32,
pub avg_lat_cri: u32,
pub static_prio: u16,
pub rerunnable_interval_wall: u64,
pub resched_interval_wall: u64,
pub run_freq: u64,
pub avg_runtime_wall: u64,
pub wait_freq: u64,
pub wake_freq: u64,
pub perf_cri: u32,
pub thr_perf_cri: u32,
pub cpuperf_cur: u32,
pub cpu_util_wall: u64,
pub cpu_util_invr: u64,
pub nr_active: u32,
pub dsq_id: u64,
pub dsq_consume_lat: u64,
}Fields
mseq: u64Sequence ID of this message
pid: i32Process ID
comm: StringTask name
stat: StringLR: ’L’atency-critical or ’R’egular, HI: performance-’H’ungry or performance-’I’nsensitive, BT: ’B’ig or li’T’tle, EG: ’E’ligible or ’G’reedy, PN: ’P’reempting or ’N’ot
cpu_id: u32CPU ID where this task is scheduled on
prev_cpu_id: u32CPU ID where a task ran last time.
suggested_cpu_id: u32CPU ID suggested when a task is enqueued.
waker_pid: i32Waker’s process ID
waker_comm: StringWaker’s task name
slice_wall: u64Assigned time slice
slice_used_wall: u64Amount of time actually used by task in a slice
lat_cri: u32Latency criticality of this task
avg_lat_cri: u32Average latency criticality in a system
static_prio: u16Static priority (20 == nice 0)
rerunnable_interval_wall: u64Time interval from the last quiescent time to this runnable time.
resched_interval_wall: u64Time interval from the last stopped time.
run_freq: u64How often this task is scheduled per second
avg_runtime_wall: u64Average runtime per schedule
wait_freq: u64How frequently this task waits for other tasks
wake_freq: u64How frequently this task wakes other tasks
perf_cri: u32Performance criticality of this task
thr_perf_cri: u32Performance criticality threshold
cpuperf_cur: u32Target performance level of this CPU
cpu_util_wall: u64CPU utilization of this CPU
cpu_util_invr: u64Invariant CPU utilization of this CPU scaled by CPU capacity and frequency
nr_active: u32Number of active CPUs when core compaction is enabled
dsq_id: u64DSQ ID where this task was dispatched from
dsq_consume_lat: u64Consume latency of this DSQ (shows how contended the DSQ is)
Implementations